@@ -1,12 +1,12 @@
 use super::Connection;
 use crate::auth::AuthFilter;
-use crate::proto::google::spanner::v1 as proto;
 use crate::{
     DatabaseId, Error, ResultSet, Session, SpannerResource, ToSpanner, Transaction,
     TransactionSelector,
 };
 use async_trait::async_trait;
 use gcp_auth::AuthenticationManager;
+use googapis::google::spanner::v1 as proto;
 use proto::{
     execute_sql_request::QueryMode, spanner_client::SpannerClient, CommitRequest,
     CreateSessionRequest, DeleteSessionRequest, ExecuteSqlRequest, RollbackRequest,
@@ -121,7 +121,7 @@ impl Connection for GrpcConnection {
         for (name, value) in parameters {
             let value = value.to_spanner()?;
             param_types.insert(name.to_string(), value.spanner_type().into());
-            params.insert(name.to_string(), value.into());
+            params.insert(name.to_string(), value.try_into()?);
         }
 
         self.spanner
