@@ -1,6 +1,8 @@
 use std::num::TryFromIntError;
 
 use bb8::RunError;
+#[cfg(feature = "temporal")]
+use chrono::ParseError;
 use derive_builder::UninitializedFieldError;
 
 #[derive(thiserror::Error, Debug)]
@@ -41,3 +43,17 @@ impl From<UninitializedFieldError> for Error {
         Error::Config(format!("{}", value))
     }
 }
+
+#[cfg(feature = "temporal")]
+impl From<ParseError> for Error {
+    fn from(p: ParseError) -> Self {
+        Error::Codec(format!("unexpected date or datetime format: {}", p))
+    }
+}
+
+#[cfg(feature = "json")]
+impl From<serde_json::Error> for Error {
+    fn from(err: serde_json::Error) -> Self {
+        Error::Codec(format!("unexpected json value: {}", err))
+    }
+}
